from flask_sqlalchemy import SQLAlchemy

db = SQLAlchemy()

class Build(db.Model):
    build_id = db.Column(db.Integer, primary_key=True, autoincrement=False)
    build_status = db.Column(db.String)
    build_device = db.Column(db.String)
    build_version = db.Column(db.String)
    build_type = db.Column(db.String)
    build_date = db.Column(db.Date)
    build_duration = db.Column(db.Integer)
    build_runner_id = db.Column(db.String, db.ForeignKey('runner.runner_id'))
    build_runner = db.relationship('Runner', backref=db.backref('builds', lazy=True))

    def __repr__(self):
        return f"{self.build_id} {self.build_device} {self.build_version} {self.build_type} {self.build_runner_id}"

    @classmethod
    def get_or_create_by_id(cls, build_id):
        build = cls.query.filter_by(build_id=build_id).first()
        return build if build else cls(build_id=build_id)

class Runner(db.Model):
    runner_id = db.Column(db.String, primary_key=True, autoincrement=False)
    runner_name = db.Column(db.String)

    runner_sponsor = db.Column(db.String)
    runner_sponsor_url = db.Column(db.String)

    @classmethod
    def get_or_create_by_id(cls, runner_id):
        runner = cls.query.filter_by(runner_id=runner_id).first()
        if not runner:
            runner = cls(runner_id=runner_id)
            db.session.add(runner)
            db.session.commit()
        return runner
